@@ -3,14 +3,16 @@ from .base import BaseMessage
 from .records import RecordUpdateMessage, RecordDeleteMessage, RecordCreateMessage
 from ..exceptions import PyOrientBadMethodCallException
 from ..constants import COMMAND_OP, FIELD_BOOLEAN, FIELD_BYTE, FIELD_CHAR, \
-    FIELD_INT, FIELD_LONG, FIELD_SHORT, FIELD_STRING, QUERY_SYNC, TX_COMMIT_OP, \
-    QUERY_GREMLIN, QUERY_ASYNC, QUERY_CMD, QUERY_TYPES
+    FIELD_INT, FIELD_LONG, FIELD_SHORT, FIELD_STRING, QUERY_SYNC, FIELD_BYTES, \
+    TX_COMMIT_OP, QUERY_GREMLIN, QUERY_ASYNC, QUERY_CMD, QUERY_TYPES, \
+    QUERY_SCRIPT
 from ..serialization import ORecordEncoder
 from ..utils import need_connected, need_db_opened, dlog
 
 
 __author__ = 'Ostico <ostico@gmail.com>'
 
+
 #
 # COMMAND_OP
 #
@@ -77,7 +79,6 @@ class CommandMessage(BaseMessage):
 
         if isinstance( params, tuple ) or isinstance( params, list ):
             try:
-
                 self.set_command_type( params[0] )
 
                 self._query = params[1]
@@ -94,6 +95,7 @@ class CommandMessage(BaseMessage):
 
         if self._command_type == QUERY_CMD \
                 or self._command_type == QUERY_SYNC \
+                or self._command_type == QUERY_SCRIPT \
                 or self._command_type == QUERY_GREMLIN:
             self._mod_byte = 's'
         else:
@@ -114,9 +116,12 @@ class CommandMessage(BaseMessage):
             _payload_definition.append( ( FIELD_INT, self._limit ) )
             _payload_definition.append( ( FIELD_STRING, self._fetch_plan ) )
 
+        if self._command_type == QUERY_SCRIPT:
+            _payload_definition.insert( 1, ( FIELD_STRING, 'sql' ) )
+
         _payload_definition.append( ( FIELD_INT, 0 ) )
 
-        payload = ''.join(
+        payload = b''.join(
             self._encode_field( x ) for x in _payload_definition
         )
 
@@ -166,7 +171,8 @@ class CommandMessage(BaseMessage):
         # type of response
         # decode body char with flag continue ( Header already read )
         response_type = self._decode_field( FIELD_CHAR )
-
+        if not isinstance(response_type, str):
+            response_type = response_type.decode()
         res = []
         if response_type == 'n':
             return None
@@ -195,19 +201,15 @@ class CommandMessage(BaseMessage):
             cached_results = self._read_async_records()
             # cache = cached_results['cached']
         else:
-            msg = ""
+            msg = b''
             import socket
             self._orientSocket._socket.settimeout(5)
-            try:
+
+            m = self._orientSocket.read(1)
+            while m != "":
+                msg += m
                 m = self._orientSocket.read(1)
-                while m != "":
-                    msg += m
-                    m = self._orientSocket.read(1)
-            except socket.timeout as e:
-                dlog("************* " + str(e) + " *************")
-                # TODO: ???
-                pass
-            exit(1)
+
 
         return res
 
@@ -285,7 +287,8 @@ class _TXCommitMessage(BaseMessage):
 
         for k, v in enumerate(self._operation_stack):
             self._append(( FIELD_BYTE, chr(1) ))  # start of records
-            map(self._append, v)
+            for field in v:
+                self._append(field)
 
         self._append(( FIELD_BYTE, chr(0) ))
         self._append(( FIELD_STRING, "" ))
@@ -406,10 +409,10 @@ class _TXCommitMessage(BaseMessage):
             self._operation_stack.append((
                 ( FIELD_BYTE, chr(1) ),
                 ( FIELD_SHORT, int(getattr(operation, "_cluster_id")) ),
-                ( FIELD_LONG, long(getattr(operation, "_cluster_position")) ),
+                ( FIELD_LONG, int(getattr(operation, "_cluster_position")) ),
                 ( FIELD_BYTE, getattr(operation, "_record_type") ),
                 ( FIELD_INT, int(getattr(operation, "_record_version")) ),
-                ( FIELD_STRING, o_record_enc.getRaw() ),
+                ( FIELD_STRING, o_record_enc.get_raw() ),
             ))
 
             if self.get_protocol() >= 23:
@@ -425,7 +428,7 @@ class _TXCommitMessage(BaseMessage):
             self._operation_stack.append((
                 ( FIELD_BYTE, chr(2) ),
                 ( FIELD_SHORT, int(getattr(operation, "_cluster_id")) ),
-                ( FIELD_LONG, long(getattr(operation, "_cluster_position")) ),
+                ( FIELD_LONG, int(getattr(operation, "_cluster_position")) ),
                 ( FIELD_BYTE, getattr(operation, "_record_type") ),
                 ( FIELD_INT, int(getattr(operation, "_record_version")) ),
             ))
@@ -434,9 +437,9 @@ class _TXCommitMessage(BaseMessage):
             self._operation_stack.append((
                 ( FIELD_BYTE, chr(3) ),
                 ( FIELD_SHORT, int(-1) ),
-                ( FIELD_LONG, long(self._temp_cluster_position_seq) ),
+                ( FIELD_LONG, int(self._temp_cluster_position_seq) ),
                 ( FIELD_BYTE, getattr(operation, "_record_type") ),
-                ( FIELD_STRING, o_record_enc.getRaw() ),
+                ( FIELD_STRING, o_record_enc.get_raw() ),
             ))
             self._pre_operation_records[
                 str(self._temp_cluster_position_seq)
