@@ -35,7 +35,7 @@ class CommandTestCase(unittest.TestCase):
                 .send().fetch_response()
             assert True
         except pyorient.PyOrientCommandException as e:
-            print(e.message)
+            print(str(e))
         finally:
             ( factory.get_message( pyorient.DB_CREATE ) ).prepare(
                 (db_name, pyorient.DB_TYPE_GRAPH, pyorient.STORAGE_TYPE_MEMORY)
@@ -117,7 +117,7 @@ class CommandTestCase(unittest.TestCase):
                 .send().fetch_response()
             assert True
         except pyorient.PyOrientCommandException as e:
-            print(e.message)
+            print(str(e))
         finally:
             ( factory.get_message( pyorient.DB_CREATE ) ).prepare(
                 (db_name, pyorient.DB_TYPE_GRAPH, pyorient.STORAGE_TYPE_MEMORY)
@@ -170,7 +170,7 @@ class CommandTestCase(unittest.TestCase):
         tx.attach( delete_msg )
         res = tx.commit()
 
-        for k, v in res.iteritems():
+        for k, v in res.items():
             print(k + " -> " + v.vacanza)
 
         assert len(res) == 4
@@ -201,7 +201,7 @@ class CommandTestCase(unittest.TestCase):
                 .send().fetch_response()
 
         except pyorient.PyOrientCommandException as e:
-            print(e.message)
+            print(str(e))
         finally:
             ( factory.get_message(pyorient.DB_CREATE) ).prepare(
                 (db_name, pyorient.DB_TYPE_GRAPH, pyorient.STORAGE_TYPE_MEMORY)
@@ -284,13 +284,13 @@ class CommandTestCase(unittest.TestCase):
         res = req_msg.prepare( [ rec_position.rid, "*:-1" ] ) \
             .send().fetch_response()
 
-        # print(res
-        # print(res.rid
-        # print(res.o_class
-        # print(res.version
-        # print(res.alloggio
-        # print(res.lavoro
-        # print(res.vacanza
+        # print(res)
+        # print(res.rid)
+        # print(res.o_class)
+        # print(res.version)
+        # print(res.alloggio)
+        # print(res.lavoro)
+        # print(res.vacanza)
 
         assert res.rid == "#11:4"
         assert res.o_class == "c_test"
@@ -304,4 +304,4 @@ class CommandTestCase(unittest.TestCase):
         #     .send().fetch_response()
 
 
-# x = CommandTestCase('test_command').run()
+# x = CommandTestCase('test_command').run()
\ No newline at end of file
